@@ -8,15 +8,19 @@ invalid <- function(model) {
 }
 
 check_arguments <- function(model, exposure_names) {
+  original_names <- exposure_names
+  modified_names <- grep(paste0("^", original_names[1], "|^", original_names[2]), names(coef(model)), value = TRUE)
+
   if (!invalid(model)) {
     stop("The 'model' argument must be a regression model object fit with glm(), coxph() or clogit()")
-  } else if (!is(exposure_names, "character")  || length(exposure_names) != 2) {
+  } else if (!is(exposure_names, "character") || length(exposure_names) != 2) {
     stop("Argument 'exposure_names' requires a character vector of the names of the two exposure variables")
-  } else if (anyNA(match(exposure_names, names(coef(model))))) {
+  } else if (length(modified_names) < 2) {
     stop("At least one of the exposure names you have identified cannot be found in your model")
   }
 }
 
+
 extract_pvals <- function(model) {
   if ("glm" %in% class(model)) {
    return(summary(model)$coefficients[,4])
